==> huaweicloudsdkcbr-3.0.53-py2.py3-none-any.whl: huaweicloudsdkcbr/v1/model/list_vault_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListVaultResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'vaults': 'list[Vault]',
        'count': 'int'
    }

    attribute_map = {
        'vaults': 'vaults',
        'count': 'count'
    }

    def __init__(self, vaults=None, count=None):
        """ListVaultResponse - a model defined in huaweicloud sdk"""
        
        super(ListVaultResponse, self).__init__()

        self._vaults = None
        self._count = None
        self.discriminator = None

        if vaults is not None:
            self.vaults = vaults
        if count is not None:
            self.count = count

    @property
    def vaults(self):
        """Gets the vaults of this ListVaultResponse.

        存储库实例列表

        :return: The vaults of this ListVaultResponse.
        :rtype: list[Vault]
        """
        return self._vaults

    @vaults.setter
    def vaults(self, vaults):
        """Sets the vaults of this ListVaultResponse.

        存储库实例列表

        :param vaults: The vaults of this ListVaultResponse.
        :type: list[Vault]
        """
        self._vaults = vaults

    @property
    def count(self):
        """Gets the count of this ListVaultResponse.

        存储库个数

        :return: The count of this ListVaultResponse.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this ListVaultResponse.

        存储库个数

        :param count: The count of this ListVaultResponse.
        :type: int
        """
        self._count = count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(sanitize_for_serialization(self))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListVaultResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcbr-3.0.66-py2.py3-none-any.whl: huaweicloudsdkcbr/v1/model/list_vault_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListVaultResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'vaults': 'list[Vault]',
        'count': 'int'
    }

    attribute_map = {
        'vaults': 'vaults',
        'count': 'count'
    }

    def __init__(self, vaults=None, count=None):
        """ListVaultResponse - a model defined in huaweicloud sdk"""
        
        super(ListVaultResponse, self).__init__()

        self._vaults = None
        self._count = None
        self.discriminator = None

        if vaults is not None:
            self.vaults = vaults
        if count is not None:
            self.count = count

    @property
    def vaults(self):
        """Gets the vaults of this ListVaultResponse.

        存储库实例列表

        :return: The vaults of this ListVaultResponse.
        :rtype: list[Vault]
        """
        return self._vaults

    @vaults.setter
    def vaults(self, vaults):
        """Sets the vaults of this ListVaultResponse.

        存储库实例列表

        :param vaults: The vaults of this ListVaultResponse.
        :type: list[Vault]
        """
        self._vaults = vaults

    @property
    def count(self):
        """Gets the count of this ListVaultResponse.

        存储库个数

        :return: The count of this ListVaultResponse.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this ListVaultResponse.

        存储库个数

        :param count: The count of this ListVaultResponse.
        :type: int
        """
        self._count = count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListVaultResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
